.. swyft documentation master file, created by
   sphinx-quickstart on Thu Nov 12 11:23:08 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to swyft's documentation!
=================================

.. centered::
   **Hyper-efficient parameter inference for complex data**

The latest version of *swyft* can be found on `github <https://github.com/undark-lab/swyft>`_.
For getting started, check out our `quickstart guide <https://colab.research.google.com/github/undark-lab/swyft/blob/master/notebooks/Quickstart.ipynb>`_ on google colab.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   swyft
   install
   autodoc
   zen

Acknowledging
-------------
If you use *swyft* in scientific publications, please cite one or both method papers.

*Simulation-efficient marginal posterior estimation with swyft: stop wasting your precious time*, Benjamin Kurt Miller, Alex Cole, Gilles Louppe, Christoph Weniger, https://arxiv.org/abs/2011.13951

*Truncated Marginal Neural Ratio Estimation*, Benjamin Kurt Miller, Alex Cole, Patrick Forré, Gilles Louppe, Christoph Weniger, https://arxiv.org/abs/2107.01214
